@@ -1,7 +1,9 @@
 package Minion::Backend::MongoDB;
-$Minion::Backend::MongoDB::VERSION = '1.07';
+$Minion::Backend::MongoDB::VERSION = '1.08';
 # ABSTRACT: MongoDB backend for Minion
 
+use 5.016; # Minion requires this so we require this.
+
 use Mojo::Base 'Minion::Backend';
 
 use boolean;
@@ -957,7 +959,7 @@ Minion::Backend::MongoDB - MongoDB backend for Minion
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -968,8 +970,8 @@ version 1.07
 =head1 DESCRIPTION
 
 This is a L<MongoDB> backend for L<Minion> derived from
-L<MongoDB::Minion::Pg> and supports for all its features.
-L<Mojolicious> 9.0 compatibility and synced with L<MongoDB::Minion::Pg> v.10.22
+L<Minion::Backend::Pg> and supports for all its features.
+L<Mojolicious> 9.0 compatibility and synced with L<Minion::Backend::Pg> v.10.22
 features.
 
 =encoding UTF-8
